<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// I
	'info_compresseur_titre' => 'بهينه‌سازي و فشرده سازي',
	'info_question_activer_compactage_css' => 'سي.اس.اس',
	'info_question_activer_compactage_js' => 'نويسه‌ها (اسكريپت‌ها)؟',
	'item_compresseur_css' => 'فعال‌سازي پرونده‌هاي شيوه‌برگه‌ها (اس.سي.سي)؟',
	'item_compresseur_js' => 'فعال‌سازي فشرده‌سازي نويسه‌ها (جاوااسكيپت)؟',

	// T
	'texte_compacter_avertissement' => 'در جريان توسعه‌ي سايت خود مراقب باشيد اين گزينه‌ها را فعال نسازيد:‌ خطازدايي از عناصر فشرده شده دشوار مي‌‌شود.',
	'texte_compacter_script_css' => 'اسپيپ مي‌تواند فايل‌هاي جاواسكريپت و شيوه‌برگه‌هاي سي.اس.اس را فشرده كرده و در فال‌هاي استاتيك صبط كند. اين كار نمايش سايت را تسريع خواهد كرد. ',
	'titre_compacter_script_css' => 'فشرده‌سازي نويسه‌ها و سي.اس.اس',
];
